==> sdc-cms-api-spaces-1.0.0.tgz: package/es/spaces/store.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import { autorun, action, observable } from 'mobx';

import { userStore } from 'sdc-auth-user';
import { CRUDStore } from 'sdc-cms-api-stores';

import api from './api';

var SpacesStore = function (_CRUDStore) {
  _inherits(SpacesStore, _CRUDStore);

  function SpacesStore(_ref) {
    var send = _ref.send,
        socket = _ref.socket,
        options = _objectWithoutProperties(_ref, ['send', 'socket']);

    _classCallCheck(this, SpacesStore);

    var _this = _possibleConstructorReturn(this, _CRUDStore.call(this, options));

    _this.reload = function () {
      _this.list({})();
    };

    _this.createSpace = function (space) {
      return _this.create({ entry: space });
    };

    _this.addSpace = function (space) {
      _this.spaces.push(space);
      _this.select(space);
    };

    _this.send = send;

    autorun(function () {
      if (userStore.user.id) {
        _this.reload();
      } else {
        _this.clearEntries();
      }
    });

    socket.on('connect', _this.reload);
    return _this;
  }

  return SpacesStore;
}(CRUDStore);

var makeSpacesStore = function makeSpacesStore(_ref2) {
  var command = _ref2.command,
      options = _objectWithoutProperties(_ref2, ['command']);

  return new SpacesStore(_extends({}, options, { api: api({ command: command }) }));
};
export { makeSpacesStore };

==> sdc-cms-api-spaces-1.1.1.tgz: package/es/spaces/store.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import { autorun, action, observable } from 'mobx';

import { userStore } from 'sdc-auth-user';
import { CRUDStore } from 'sdc-cms-api-stores';

import api from './api';

var SpacesStore = function (_CRUDStore) {
  _inherits(SpacesStore, _CRUDStore);

  function SpacesStore(_ref) {
    var send = _ref.send,
        socket = _ref.socket,
        options = _objectWithoutProperties(_ref, ['send', 'socket']);

    _classCallCheck(this, SpacesStore);

    var _this = _possibleConstructorReturn(this, _CRUDStore.call(this, options));

    _this.reload = function () {
      _this.list({})();
    };

    _this.createSpace = function (space) {
      return _this.create({ entry: space });
    };

    _this.deleteSpace = function (space) {
      return _this.remove(space._id);
    };

    _this.send = send;

    autorun(function () {
      if (userStore.user.id) {
        _this.reload();
      } else {
        _this.clearEntries();
      }
    });

    socket.on('connect', _this.reload);
    return _this;
  }

  return SpacesStore;
}(CRUDStore);

var makeSpacesStore = function makeSpacesStore(_ref2) {
  var command = _ref2.command,
      options = _objectWithoutProperties(_ref2, ['command']);

  return new SpacesStore(_extends({}, options, { api: api({ command: command }) }));
};
export { makeSpacesStore };
